package com.ruoyi.zongzhi.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.zongzhi.domain.TcDataSourceTj;
import com.ruoyi.zongzhi.service.TcDataSourceTjService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.List;

/**
 * 数据来源统计表(TcDataSourceTj)表控制层
 *
 * @author wu
 * @since 2023-09-12 14:55:53
 */
@RestController
@RequestMapping("zongzhi/tcDataSourceTj")
@Api(tags = "数据来源统计表")
@Transactional(rollbackFor = Exception.class)
public class TcDataSourceTjController extends BaseController {
    /**
     * 服务对象
     */
    @Resource
    private TcDataSourceTjService tcDataSourceTjService;

    /**
     * 分页条件查询所有数据
     *
     * @param page           分页条件
     * @param tcDataSourceTj 查询条件
     * @return 所有数据
     */
    @GetMapping
    @ApiOperation(value = "分页条件查询数据来源统计表", response = TcDataSourceTj.class)
    public AjaxResult page(Page<TcDataSourceTj> page, TcDataSourceTj tcDataSourceTj) {
        return success(tcDataSourceTjService.page(page, new QueryWrapper<>(tcDataSourceTj)));
    }

    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @GetMapping("{id}")
    @ApiOperation(value = "通过主键查询单条数据来源统计表", response = TcDataSourceTj.class)
    public AjaxResult getById(@PathVariable Serializable id) {
        return success(tcDataSourceTjService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param tcDataSourceTj 实体对象
     * @return 新增结果
     */
    @PostMapping
    @ApiOperation(value = "新增数据来源统计表", response = TcDataSourceTj.class)
    public AjaxResult insert(@RequestBody TcDataSourceTj tcDataSourceTj) {
        return success(tcDataSourceTjService.save(tcDataSourceTj));
    }

    /**
     * 修改数据
     *
     * @param tcDataSourceTj 实体对象
     * @return 修改结果
     */
    @PutMapping
    @ApiOperation(value = "修改数据来源统计表")
    public AjaxResult update(@RequestBody TcDataSourceTj tcDataSourceTj) {
        return success(tcDataSourceTjService.updateById(tcDataSourceTj));
    }

    /**
     * 删除数据
     *
     * @param idList 主键集合
     * @return 删除结果
     */
    @DeleteMapping
    @ApiOperation(value = "删除数据来源统计表")
    public AjaxResult delete(@RequestParam("idList") List<Long> idList) {
        return success(tcDataSourceTjService.removeByIds(idList));
    }
}

